<?php

App::uses('ModelBehavior', 'Behavior');

class PayableBehavior extends ModelBehavior {

/**
 * Setup behavior
 *
 * @param Model $Model
 * @param array $settings
 * @return void
 */
	public function setup(Model $Model, $settings = array()) {
		parent::setup($Model, $settings);

		$this->settings[$Model->alias] = array_merge(
			$settings
		);

		return;
	}

/**
 * Returns payment details for passing to the API
 *
 * @param Model $Model
 * @param int $id Model ID
 * @param string $model
 * @return array
 */
	public function getPaymentDetails(Model $Model, $id, $model = null) {
		$data = [
			'vendorTxCode' => '',
			'vpstxId' => '',
			'status' => 'OK',
			'txauthno' => ''
		];
		if ($model === null) {
			$model = (!empty($Model->plugin) ? $Model->plugin . '.' : '') . $Model->alias;
		}
		switch (Configure::read('BuzzPurchase.payment_gateway')) {
			case 'redsys':
				$this->_generateRedSysPaymentDetails($id, $model, $data);
				break;
		}

		return $data;
	}

/**
 * Get the Redsys payment details.
 *
 * @param int $id
 * @param string $model
 * @param array &$data
 */
	protected function _generateRedSysPaymentDetails($id, $model, array &$data) {
		$result = ClassRegistry::init('Transactions.Transaction')->find(
			'first',
			[
				'fields' => ['Redsys.*'],
				'joins' => [
					[
						'table' => 'transactions_redsys',
						'alias' => 'Redsys',
						'type' => 'INNER',
						'conditions' => 'Redsys.transaction_id = Transaction.id'
					]
				],
				'conditions' => [
					'Transaction.model_id' => $id,
					'Transaction.model' => $model
				],
				'order' => ['Redsys.created' => 'DESC']
			]
		);

		if (!empty($result)) {
			$data = [
				'vendorTxCode' => $result['Redsys']['order'],
				'vpstxId' => $result['Redsys']['signature'],
				'status' => 'OK',
				'txauthno' => $result['Redsys']['authorisation_code']
			];
		}
	}

}
